@@ -6,15 +6,15 @@
 //! which can be passed around between different parts of a program.
 //!
 //! Two notable features are the [`Dir`] and [`Pool`] types:
-//!  - `Dir` represents an open directory in a filesystem. Instead of
-//!    opening files by absolute paths or paths relative to the current
-//!    working directory, files are opened via paths relative to a
-//!    `Dir`. The concepts of a process-wide "current working directory"
-//!    and a single global filesystem namespace are de-emphasized.
-//!  - `Pool` represents a set of network addresses. Instead of
-//!    allowing applications to request access to any address and then
-//!    applying process-wide filtering rules, filtering rules are
-//!    built into pools which may be passed through the program.
+//!  - `Dir` represents an open directory in a filesystem. Instead of opening
+//!    files by absolute paths or paths relative to the current working
+//!    directory, files are opened via paths relative to a `Dir`. The concepts
+//!    of a process-wide "current working directory" and a single global
+//!    filesystem namespace are de-emphasized.
+//!  - `Pool` represents a set of network addresses. Instead of allowing
+//!    applications to request access to any address and then applying
+//!    process-wide filtering rules, filtering rules are built into pools which
+//!    may be passed through the program.
 //!
 //! On WASI, use of this library closely reflects the underlying system
 //! API, so it avoids compatibility layers.
@@ -45,4 +45,6 @@ pub mod time;
 // For now, re-export `path`; see
 // <https://github.com/bytecodealliance/cap-std/issues/88>
 pub use async_std::path;
+#[doc(hidden)]
+pub use cap_primitives::ambient_authority_known_at_compile_time;
 pub use cap_primitives::{ambient_authority, AmbientAuthority};
